@@ -1,6 +1,6 @@
 <?php
 
-# FitGallery 1.00
+# FitGallery 1.01
 # (C) Copyright  Omar Lpez 'pollo', Enrique D. Bosch 'presi'
 # http://fitgallery.presi.org
 #
@@ -155,7 +155,7 @@ if ($para2 >= $numero_arch) $para2 = $nummenosuno;
 for ( $i=$para ; $i <= $para2 ; $i++) 
     html_image($ruta,$galeria,$arr[$i]['medium'],$text_medium,$h_thumb,$i,$arr[$i]['file'],
                $arr[$i]['size'],$arr[$i]['bytes'],$arr[$i]['date'],
-               $arr[$i]['exif'],$text_exif,&$any_exif,$arr[$i]['dur']);
+               $arr[$i]['exif'],$text_exif,$any_exif,$arr[$i]['dur']);
 
 html_sep();
 
